@@ -1,4 +1,4 @@
-# Copyright 2008 Lowell Alleman
+# Copyright 2013 Lowell Alleman
 #
 #   Licensed under the Apache License, Version 2.0 (the "License"); you may not
 #   use this file except in compliance with the License. You may obtain a copy
@@ -44,7 +44,7 @@ See the README file for an example usage of this module.
 """
 
 
-__version__ = "$Id: cloghandler.py 6175 2009-11-02 18:40:35Z lowell $"
+__version__ = 'lowell87@gmail.com-20130704072400-dn7y6558wqhas59f 2013-07-04 03:24:00 -0400 [0]'
 __author__ = "Lowell Alleman"
 __all__ = [
     "ConcurrentRotatingFileHandler",
@@ -69,7 +69,7 @@ except ImportError:
 # class, right? We do some rename checking... that should prevent some file
 # clobbering that the builtin class allows.
 
-# sibling  module than handles all the ugly platform-specific details of file locking
+# sibling module than handles all the ugly platform-specific details of file locking
 from portalocker import lock, unlock, LOCK_EX, LOCK_NB, LockException
 
 
@@ -161,7 +161,7 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
         self._rotateFailed = False
         self.maxBytes = maxBytes
         self.backupCount = backupCount
-        # Prevent multiple extensions on the lock file (Only handles the normal "*.log" case.)
+        # Use 'file.lock' and not 'file.log.lock' (Only handles the normal "*.log" case.)
         if filename.endswith(".log"):
             lock_file = filename[:-4]
         else:
@@ -191,9 +191,10 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
         """ Release file and thread locks. Flush stream and take care of closing
         stream in 'degraded' mode. """
         try:
-            self.stream.flush()
-            if self._rotateFailed:
-                self.stream.close()
+            if not self.stream.closed:
+                self.stream.flush()
+                if self._rotateFailed:
+                    self.stream.close()
         finally:
             try:
                 unlock(self.stream_lock)
